@@ -9,22 +9,14 @@ from cognite.experimental._api.assets import ExperimentalAssetsAPI
 from cognite.experimental._api.entity_extraction import EntityExtractionAPI
 from cognite.experimental._api.entity_matching import EntityMatchingAPI
 from cognite.experimental._api.functions import FunctionsAPI
-from cognite.experimental._api.labels import LabelsAPI
 from cognite.experimental._api.model_hosting import ModelHostingAPI
 from cognite.experimental._api.pnid_parsing import PNIDParsingAPI
 from cognite.experimental._api.relationships import RelationshipsAPI
 from cognite.experimental._api.resource_typing import ResourceTypingAPI
-from cognite.experimental._api.synthetic_time_series import SyntheticDatapointsAPI
 from cognite.experimental._api.types import TypesAPI
 from cognite.experimental._api.unstructured import GrepAPI
 
 
-class ExperimentalDatapointsApi(DatapointsAPI):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.synthetic = SyntheticDatapointsAPI(self._config, api_version="playground", cognite_client=self)
-
-
 class ExperimentalFilesApi(FilesAPI):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -70,7 +62,7 @@ class CogniteClient(Client):
         if client_name is None and not os.environ.get("COGNITE_CLIENT_NAME"):
             client_name = "Cognite Experimental SDK"
 
-        if api_key is None and not os.environ.get("COGNITE_API_KEY") and project is not None:
+        if token is None and (api_key is None and not os.environ.get("COGNITE_API_KEY") and project is not None):
             key = project.upper().replace("-", "_") + "_API_KEY"
             if os.environ.get(key):
                 api_key = os.environ[key]
@@ -92,13 +84,11 @@ class CogniteClient(Client):
             debug,
         )
         self.relationships = RelationshipsAPI(self._config, api_version="playground", cognite_client=self)
-        self.datapoints = ExperimentalDatapointsApi(self._config, api_version="v1", cognite_client=self)
         self.files = ExperimentalFilesApi(self._config, api_version="v1", cognite_client=self)
         self.model_hosting = ModelHostingAPI(self._config, api_version="playground", cognite_client=self)
 
         self.assets_playground = ExperimentalAssetsAPI(self._config, api_version="playground", cognite_client=self)
         self.types = TypesAPI(self._config, api_version="playground", cognite_client=self)
-        self.labels = LabelsAPI(self._config, api_version="playground", cognite_client=self)
 
         self.entity_matching = EntityMatchingAPI(self._config, api_version="playground", cognite_client=self)
         self.entity_extraction = EntityExtractionAPI(self._config, api_version="playground", cognite_client=self)
